# hardened build if not overriden
%{!?_hardened_build:%global _hardened_build 1}

%if %{?_hardened_build}%{!?_hardened_build:0}
%global cflags_harden -fpie
%global ldflags_harden -pie -z relro -z now
%endif

Summary: Alternative packet radio system for Linux
Name: uronode
Version: 2.2
Release: 1%{?dist}
License: GPLv2+
Group: Applications/Communications
URL: http://www.n1uro.net
BuildRequires: zlib-devel, libax25-devel, systemd
Requires(post): systemd
Requires(preun): systemd
Requires(postun): systemd
Source0: ftp://ftp.n1uro.net/packet/%{name}-%{version}.tar.gz
Source1: flexd.service
Source2: uronode@.service
Source3: uronode.socket
Source4: uronode.xinetd
Source5: uronode-README.fedora
Patch0: uronode-2.1-non-interactive-configure.patch
Patch1: uronode-2.2-install-fix.patch
Patch2: uronode-2.2-no-md2.patch
Patch3: uronode-2.2-ax25-build-fix.patch

%description
URONode is an alternative packet radio system for Linux. It supports
cross-port digipeating, automatic importing of flexnet routing,
various IP functions, and ANSI colors.

%prep
%setup -q
%patch0 -p1 -b .non-interactive-setup
%patch1 -p1 -b .install-fix
%patch2 -p1 -b .no-md2
%patch3 -p1 -b .ax25-build-fix

# Copy Fedora readme into place
cp -p %{SOURCE5} README.fedora

# Removing bundled libax25, using system one.
rm -rf include

# Remove binaries
rm -f ./calibrate

%build
export NON_INTERACTIVE=1
./configure
make %{?_smp_mflags} CFLAGS="%{optflags} %{?cflags_harden}" LDFLAGS="%{?__global_ldflags} %{?ldflags_harden}"

%install
make %{?_smp_mflags} DESTDIR=%{buildroot} install

# Systemd
install -Dpm 644 %{SOURCE1} %{buildroot}%{_unitdir}/flexd.service
install -Dpm 644 %{SOURCE2} %{buildroot}%{_unitdir}/uronode@.service
install -Dpm 644 %{SOURCE3} %{buildroot}%{_unitdir}/uronode.socket

# xinetd
install -Dpm 644 %{SOURCE4} %{buildroot}%{_datadir}/%{name}/xinetd.d/uronode

# ghost files
touch %{buildroot}/%{_var}/{lib/flexd/destinations,lib/uronode/mheard.dat}
# assert for case upstream would add default content
[ -s %{buildroot}%{_var}/lib/flexd/gateways ] && exit 1
[ -s %{buildroot}%{_var}/log/uronode/lastlog ] && exit 1
[ -s %{buildroot}%{_var}/lib/uronode/loggedin ] && exit 1

%post
%systemd_post flexd.service uronode.socket

%preun
%systemd_preun flexd.service uronode.socket

%postun
%systemd_postun_with_restart flexd.service uronode.socket

%files
%doc README.fedora README URONode.his FAQ COLORS CHANGES.1 CHANGES.2

%{_sbindir}/*
%{_mandir}/*/*
%config(noreplace) %{_sysconfdir}/ax25/flexd.conf
%config(noreplace) %{_sysconfdir}/ax25/uronode.conf
%config(noreplace) %{_sysconfdir}/ax25/uronode.info
%config(noreplace) %{_sysconfdir}/ax25/uronode.motd
%config(noreplace) %{_sysconfdir}/ax25/uronode.perms
%config(noreplace) %{_sysconfdir}/ax25/uronode.routes
%config(noreplace) %{_sysconfdir}/ax25/uronode.users
%{_datadir}/%{name}/xinetd.d/uronode
%{_unitdir}/flexd.service
%{_unitdir}/uronode@.service
%{_unitdir}/uronode.socket
%{_datadir}/%{name}
%dir %{_var}/log/uronode
%dir %{_var}/lib/flexd
%dir %{_var}/lib/uronode
%ghost %{_var}/lib/uronode/loggedin
%ghost %{_var}/lib/flexd/gateways
%ghost %{_var}/log/uronode/lastlog
%ghost %{_var}/lib/flexd/destinations
%ghost %{_var}/lib/uronode/mheard.dat

%changelog
* Wed Dec  3 2014 Jaroslav Škarvada <jskarvad@redhat.com> - 2.2-1
- New version
- Updated ax25-build-fix patch, now flexd.c is affected
- Dropped flexd-pidfile, ipv6 patches (all upstreamed)
- Dropped md2 code (cherry-picked from upstream, by no-md2 patch)
- Fixed debuginfo
- Switched description to American English
- Switched to systemd socket activation from xinetd (xinetd is optional)

* Wed Jul 30 2014 Jaroslav Škarvada <jskarvad@redhat.com> - 2.1-2
- Fixed FHS issues related to var directory

* Tue Jul 15 2014 Jaroslav Škarvada <jskarvad@redhat.com> - 2.1-1
- Initial release
